#
# spec file for package firehol
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           firehol
Version:        3.1.5
Release:        bp153.1.18
Summary:        Tools to build stateful firewalls and traffic shaping
License:        GPL-2.0
Group:          Productivity/Networking/Security
Url:            http://firehol.org/
Source:         https://github.com/firehol/firehol/releases/download/v%{version}/firehol-%{version}.tar.xz
Source99:       %{name}-rpmlintrc
BuildRequires:  curl
BuildRequires:  fdupes
BuildRequires:  git-core
BuildRequires:  iprange
BuildRequires:  iproute2
BuildRequires:  ipset
BuildRequires:  iptables
BuildRequires:  iputils
BuildRequires:  jq
BuildRequires:  kmod
BuildRequires:  less
BuildRequires:  ncurses-utils
BuildRequires:  nfacct
BuildRequires:  pkgconfig
BuildRequires:  procps
BuildRequires:  screen
BuildRequires:  tcpdump
BuildRequires:  traceroute
BuildRequires:  unzip
BuildRequires:  util-linux-systemd
BuildRequires:  wget
BuildRequires:  whois
BuildRequires:  pkgconfig(systemd)
Requires:       curl
Requires:       iprange
Requires:       iproute2
Requires:       ipset
Requires:       iptables
Requires:       iputils
Requires:       kmod
Requires:       nfacct
Requires:       procps
Requires:       screen
Requires:       tcpdump
Requires:       traceroute
Requires:       util-linux-systemd
Recommends:     git-core
Recommends:     jq
Recommends:     less
Recommends:     ncurses-utils
Recommends:     unzip
Recommends:     wget
Recommends:     whois
BuildArch:      noarch

%description
FireHOL is a language (and a program to run it) which builds stateful firewalls
from human-readable configuration files.

FireQOS is a program which sets up traffic shaping from human-readable
configuration files.

Both programs abstract away the differences between IPv4 and IPv6, and rules
for each protocol can be applied as needed.

%package doc
Summary:        FireHOL documentation
Group:          Documentation/Other
BuildArch:      noarch

%description doc
Contains documentation and configuration examples for FireHOL.


%prep
%setup -q

%build
%configure --docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
%make_install
install -d %{buildroot}%{_unitdir}

cp %{buildroot}%{_docdir}/%{name}/contrib/*.service %{buildroot}%{_unitdir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcfirehol
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcfireqos

chmod -Rv o= %{buildroot}%{_sysconfdir}/firehol/

%fdupes -s %{buildroot}%{_mandir}

%pre
%service_add_pre firehol.service fireqos.service

%preun
%service_del_preun firehol.service fireqos.service

%post
%service_add_post firehol.service fireqos.service

%postun
%service_del_postun firehol.service fireqos.service

%files
%defattr(-,root,root)
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/firehol/
%{_sbindir}/firehol
%{_sbindir}/fireqos
%{_sbindir}/link-balancer
%{_sbindir}/update-ipsets
%{_sbindir}/vnetbuild
%{_libexecdir}/firehol/
%{_datadir}/update-ipsets/
%{_sbindir}/rcfirehol
%{_sbindir}/rcfireqos
%{_unitdir}/fire*service

%files doc
%doc ChangeLog COPYING README THANKS
%{_docdir}/%{name}
%{_mandir}/man1/firehol.1%{ext_man}
%{_mandir}/man1/fireqos.1%{ext_man}
%{_mandir}/man1/vnetbuild.1%{ext_man}
%{_mandir}/man5/firehol*.5%{ext_man}
%{_mandir}/man5/fireqos*.5%{ext_man}
%{_mandir}/man5/vnetbuild*.5%{ext_man}

%changelog
* Sun Sep 17 2017 9@cirno.systems
  firehol (3.1.5) - 2017-09-17
  * FireHOL
  - Fix some links in documentation
  * FireQOS
  - Insert a rawmark mask if none specified
  * Update-Ipsets
  - Support serving ipset files from local web server
  - Lower pressure on github
* Sun Aug 20 2017 9@cirno.systems
  firehol (3.1.4) - 2017-08-20
  * FireHOL
  - Google hangouts port range fix #235
  - Fix hashlimit option names #223
  - Documentation improvements, marks #184 and cthelper #94
  - Allow negating interface in blacklist #143
  * FireQOS
  - DSCP match fixes #248
  - TCP match fix #249
  - Improve docs on using act_connmark to match ingress marked traffic #231
  * Update-Ipsets
  - Added various lists, removed discontinued ones
  - Include URL in user agent string in #217
  - Relax umask to allow stats collection by netdata #221
* Sun Jul  9 2017 jengelh@inai.de
- Avoid duplicate expansion of %%service_*
- firehol-doc subpackage ought to be noarch
* Wed Mar 29 2017 9@cirno.systems
  firehol (3.1.3) - 2017-02-17
  * FireHOL
  - Be more strict when detecting address ranges
    Fixes #199 where hostnames such as x-2.example.com are incorrectly
    identified as ranges.
  * Common
  - Create relative links to binaries, which prevents errors when
    installing with DESTDIR other than /
    Fix for #178 and #201 proposed by @kneeke
  firehol (3.1.2) - 2017-02-05
  * FireHOL
  - Include user policies in chains before handling orphans. Fixes NFS
    client where FIREHOL_DROP_ORPHAN_TCP_* options are in force.
  - Do not allow server/client statements without any effect on the
    firewall; #193
  - Saved firewall contents made reproducible by always zeroing counters
    and removing the dates from comments
  * FireQOS
  - Example had an ambiguous shebang which has been removed
  * Common
  - Running "make check" now exits non-zero if a test failed or none ran
  - Various copyright updates
  - Fixed pull requests from external repositories; these would previously
    fail to build on Travis
* Thu Feb  2 2017 9@cirno.systems
- 3.1.1
